[jboss-cvs] JBossAS SVN: r70855 - projects/aop/trunk/asintegration/src/main/org/jboss/aop/deployment.

jboss-cvs-commits at lists.jboss.org jboss-cvs-commits at lists.jboss.org
Thu Mar 13 21:38:10 EDT 2008


Author: kabir.khan at jboss.com
Date: 2008-03-13 21:38:10 -0400 (Thu, 13 Mar 2008)
New Revision: 70855

Modified:
   projects/aop/trunk/asintegration/src/main/org/jboss/aop/deployment/AspectManagerService.java
Log:
Initialise AspectManager before setting values

Modified: projects/aop/trunk/asintegration/src/main/org/jboss/aop/deployment/AspectManagerService.java
===================================================================
--- projects/aop/trunk/asintegration/src/main/org/jboss/aop/deployment/AspectManagerService.java	2008-03-14 01:06:52 UTC (rev 70854)
+++ projects/aop/trunk/asintegration/src/main/org/jboss/aop/deployment/AspectManagerService.java	2008-03-14 01:38:10 UTC (rev 70855)
@@ -111,7 +111,11 @@
    public AspectManagerService()
    {
       //This constructor shouuld only get called when used in JBoss 4.x.x, not in JBoss 5.
-      //In JBoss 4 we need to maintain this field  
+      //In JBoss 4 we need tomaintain this field
+      
+      //Initialise the manager
+      @SuppressWarnings("unused")
+      AspectManager manager = AspectManager.instance();
       AspectManager.maintainAdvisorMethodInterceptors = true;
    }
 




More information about the jboss-cvs-commits mailing list